=======================================================
 2020-09-20 'OpenStack TC approved release' definition
=======================================================

The OpenStack Foundation bylaws require that the Technical Committee
designates a subset of the OpenStack project as "OpenStack Technical
Committee Approved Release". A subset of that subset is then used by the
board to determine "Trademark Designated OpenStack Software".

Historically, the TC used a tag to define which deliverables among
OpenStack official deliverables were part of the "OpenStack Technical
Committee Approved Release". However it recently made the decision to
stop using a tag, and consider all official deliverables to be part of it.

This TC resolution therefore affirms that the "OpenStack Technical Committee
Approved Release", as far as the OpenStack Foundation bylaws are concerned,
shall consist of *all* deliverables created by official
:doc:`../reference/projects/index`.
